/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef FEDGE_H
#define FEDGE_H

#include "fpm.h"
#include "wNode.h"

#ifndef SWIG
namespace fpm
{

/**
 * @brief Common edge of three elements
 * @authors Adrien Crovato
 * @todo copy-pasted from waves/flow/wFace.h
 */
class FPM_API Edge
{
public:
    std::vector<tbox::Node *> nods;
    tbox::Element *el0;
    tbox::Element *el1;
    tbox::Element *el2;

    Edge(std::vector<tbox::Node *> const &_nods) : nods(_nods), el0(NULL), el1(NULL), el2(NULL) {}
};

/**
 * @brief Edge comparator
 * @authors Adrien Crovato, Romain Boman
 * @todo copy-pasted from waves/flow/wFace.h
 */
class FPM_API EquEdge
{
public:
    // Default parameters
    static const size_t bucket_size = 4;
    static const size_t min_buckets = 8;
    // Function returning a unique size_t per Edge
    size_t operator()(Edge *const f) const
    {
        size_t sum = 0;
        for (auto n : f->nods)
            sum += static_cast<size_t>(n->no);

        return sum; // sum of nodes id
    }
    // Function allowing to univoquely identify a Edge
    bool operator()(Edge *const f0, Edge *const f1) const
    {
        bool flag = false;
        size_t cnt = 0;
        // compare nodes of f0 to nodes of f1
        for (auto n0 : f0->nods)
        {
            for (auto n1 : f1->nods)
            {
                if (n0 == n1)
                {
                    cnt++;
                    break;
                }
            }
            if (cnt == 0)
                break;
        }
        // check the number of shared nodes
        if (cnt == f0->nods.size())
            flag = true;

        return flag; // true if f0 = f1 (ie, f0 and f1 share the same nodes)
    }
};

} // namespace fpm
#endif

#endif //FEDGE_H
