#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Naca 0012 wing
# Adrien Crovato

from fwk.testing import *
import math

def main():
    p = {}
    # geometry parameters
    p['sym'] = 0
    p['spn'] = 5 # true span if sym=0, half span if sym=1
    p['pars'] = {'symY' : p['sym'],'wSpn' : p['spn'], 'wNc' : 100, 'wNs' : 10} 
    # flow parameters
    p['aoa'] = 3 * math.pi / 180 
    p['aos'] = 0
    p['mach'] = 0
    # run
    import fpm.models.n0012 as n12
    solver = n12.main(p)
    # test
    print(ccolors.ANSI_BLUE + 'PyTesting...' + ccolors.ANSI_RESET)
    tests = CTests()
    if(p['aoa'] == 0 * math.pi / 180 and p['mach'] == 0):
        tests.add(CTest('CL', solver.Cl, 0.00000, 5e-2)) # aero (old code) = 0.00000
        tests.add(CTest('CD', solver.Cd, 0.00021, 5e-2)) # aero (old code) = 0.00013
        tests.add(CTest('CS', solver.Cs, -0.00000, 5e-2))
        tests.add(CTest('CM', solver.Cm, -0.00000, 5e-2))
    if(p['aoa'] == 3 * math.pi / 180 and p['mach'] == 0):
        tests.add(CTest('CL', solver.Cl, 0.229, 5e-2)) # aero (old code) = 0.226
        tests.add(CTest('CD', solver.Cd, 0.003, 5e-2)) # aero (old code) = 0.003
        tests.add(CTest('CS', solver.Cs, -0.000, 5e-2))
        tests.add(CTest('CM', solver.Cm, -0.056, 5e-2))
    tests.run()
    
    # eof
    print('')

if __name__ == '__main__':
    main()

